@@ -3,11 +3,6 @@
 require 'simplecov'
 SimpleCov.start
 
-require 'codecov'
-if ENV['CI'] == 'true'
-  SimpleCov.formatter = SimpleCov::Formatter::Codecov
-end
-
 ENV['NANOC_DEV_MODE'] = 'true'
 
 require 'fuubar'
