@@ -11,12 +11,11 @@ require 'yaml'
 # External gems
 require 'concurrent-ruby'
 require 'json_schema'
-require 'ddmemoize'
 require 'ddmetrics'
 require 'ddplugin'
 require 'hamster'
+require 'memo_wise'
 require 'slow_enumerator_tools'
-require 'tomlrb'
 require 'tty-platform'
 require 'zeitwerk'
 
@@ -39,7 +38,7 @@ module Nanoc
     #
     # @api private
     def self.version_information
-      "Nanoc #{Nanoc::VERSION} © 2007–2021 Denis Defreyne.\n" \
+      "Nanoc #{Nanoc::VERSION} © 2007–2022 Denis Defreyne.\n" \
       "Running #{RUBY_ENGINE} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} with RubyGems #{Gem::VERSION}.\n"
     end
 
@@ -52,8 +51,6 @@ module Nanoc
   end
 end
 
-DDMemoize.enable_metrics
-
 inflector_class = Class.new(Zeitwerk::Inflector) do
   def camelize(basename, abspath)
     case basename
@@ -76,15 +73,3 @@ loader.eager_load
 require_relative 'core/core_ext/array'
 require_relative 'core/core_ext/hash'
 require_relative 'core/core_ext/string'
-
-# Tracking issue:
-# https://github.com/nanoc/features/issues/24
-Nanoc::Core::Feature.define('live_cmd', version: '4.11')
-
-# Tracking issue:
-# https://github.com/nanoc/features/issues/40
-Nanoc::Core::Feature.define('toml', version: '4.11')
-
-# Tracking issue:
-# https://github.com/nanoc/features/issues/20
-Nanoc::Core::Feature.define('binary_compiled_content_cache', version: '4.11')
