@@ -3,9 +3,9 @@
 module Nanoc
   module Core
     class ActionSequence
-      include Nanoc::Core::ContractsSupport
+      # include Nanoc::Core::ContractsSupport
       include Enumerable
-      DDMemoize.activate(self)
+      prepend MemoWise
 
       attr_reader :item_rep
       attr_reader :actions
@@ -15,42 +15,43 @@ module Nanoc
         @actions = actions
       end
 
-      contract C::None => Numeric
+      # contract C::None => Numeric
       def size
         @actions.size
       end
 
-      contract Numeric => C::Maybe[Nanoc::Core::ProcessingAction]
+      # contract Numeric => C::Maybe[Nanoc::Core::ProcessingAction]
       def [](idx)
         @actions[idx]
       end
 
-      contract C::None => C::ArrayOf[Nanoc::Core::ProcessingAction]
+      # contract C::None => C::ArrayOf[Nanoc::Core::ProcessingAction]
       def snapshot_actions
         @actions.select { |a| a.is_a?(Nanoc::Core::ProcessingActions::Snapshot) }
       end
 
-      contract C::None => Array
+      # contract C::None => Array
       def paths
         snapshot_actions.map { |a| [a.snapshot_names, a.paths] }
       end
 
-      memoized def serialize
+      def serialize
         serialize_uncached
       end
+      memo_wise :serialize
 
-      contract C::None => Array
+      # contract C::None => Array
       def serialize_uncached
         to_a.map(&:serialize)
       end
 
-      contract C::Func[Nanoc::Core::ProcessingAction => C::Any] => self
+      # contract C::Func[Nanoc::Core::ProcessingAction => C::Any] => self
       def each
         @actions.each { |a| yield(a) }
         self
       end
 
-      contract C::Func[Nanoc::Core::ProcessingAction => C::Any] => self
+      # contract C::Func[Nanoc::Core::ProcessingAction => C::Any] => self
       def map
         self.class.new(
           @item_rep,
