@@ -4,9 +4,9 @@ module Nanoc
   module Core
     module OutdatednessRules
       class CodeSnippetsModified < Nanoc::Core::OutdatednessRule
-        DDMemoize.activate(self)
+        prepend MemoWise
 
-        include Nanoc::Core::ContractsSupport
+        # include Nanoc::Core::ContractsSupport
 
         affects_props :raw_content, :attributes, :compiled_content, :path
 
@@ -18,13 +18,14 @@ module Nanoc
 
         private
 
-        memoized def any_snippets_modified?(outdatedness_checker)
+        def any_snippets_modified?(outdatedness_checker)
           outdatedness_checker.site.code_snippets.any? do |cs|
             ch_old = outdatedness_checker.checksum_store[cs]
             ch_new = outdatedness_checker.checksums.checksum_for(cs)
             ch_old != ch_new
           end
         end
+        memo_wise :any_snippets_modified?
       end
     end
   end
