@@ -34,18 +34,20 @@ require 'uri'
 
 # Load extracted Nanoc dependencies
 require 'nanoc-core'
+require 'nanoc-cli'
+require 'nanoc-checking'
+require 'nanoc-deploying'
 
 # Re-export from Nanoc::Core
 Nanoc::Identifier = Nanoc::Core::Identifier
 Nanoc::DataSource = Nanoc::Core::DataSource
 Nanoc::Filter = Nanoc::Core::Filter
 Nanoc::Error = Nanoc::Core::Error
+Nanoc::Check = Nanoc::Checking::Check
 
 # Load Nanoc
 require 'nanoc/version'
-require 'nanoc/base'
 require 'nanoc/checking'
-require 'nanoc/deploying'
 require 'nanoc/extra'
 require 'nanoc/data_sources'
 require 'nanoc/filters'
