@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 module ::Sass::Script::Functions
-  def nanoc(string, params)
+  def nanoc(string, params = {})
     assert_type string, :String
     assert_type params, :Hash
     result = options[:importer].filter.instance_eval(string.value)
