@@ -14,6 +14,11 @@ describe Nanoc::Helpers::Rendering, helper: true do
     before do
       ctx.create_layout(layout_content, {}, layout_identifier)
       ctx.update_action_sequence(layout, action_sequence_for_layout)
+
+      ctx.create_item('some item', {}, '/some.md')
+      ctx.item = ctx.items['/some.md']
+      ctx.create_rep(ctx.item, '/some.html')
+      ctx.item_rep = ctx.item.reps[:default]
     end
 
     context 'legacy identifier' do
@@ -90,13 +95,31 @@ describe Nanoc::Helpers::Rendering, helper: true do
         it { is_expected.to eql('blah Nanoc::Core::Layout') }
       end
 
+      context 'printing wrapped item class' do
+        let(:layout_content) { 'item=<%= @item.class %>' }
+
+        it { is_expected.to eql('item=Nanoc::Core::CompilationItemView') }
+      end
+
+      context 'printing wrapped item rep class' do
+        let(:layout_content) { 'item_rep=<%= @item_rep.class %>' }
+
+        it { is_expected.to eql('item_rep=Nanoc::Core::CompilationItemRepView') }
+      end
+
+      context 'printing wrapped rep class' do
+        let(:layout_content) { 'rep=<%= @rep.class %>' }
+
+        it { is_expected.to eql('rep=Nanoc::Core::CompilationItemRepView') }
+      end
+
       context 'unknown layout' do
         subject { helper.instance_eval { render('/unknown.erb') } }
 
         let(:layout_content) { 'blah' }
 
         it 'raises' do
-          expect { subject }.to raise_error(Nanoc::Int::Errors::UnknownLayout)
+          expect { subject }.to raise_error(Nanoc::Core::Errors::UnknownLayout)
         end
       end
 
@@ -120,7 +143,7 @@ describe Nanoc::Helpers::Rendering, helper: true do
         let(:layout_content) { 'blah' }
 
         it 'raises' do
-          expect { subject }.to raise_error(Nanoc::Int::Errors::CannotDetermineFilter)
+          expect { subject }.to raise_error(Nanoc::Core::Errors::CannotDetermineFilter)
         end
       end
 
