@@ -29,19 +29,19 @@ describe 'GH-1328', site: true, stdio: true do
 
   it 'fails check for foo.html' do
     expect { Nanoc::CLI.run(%w[check ilinks]) }
-      .to raise_error(Nanoc::Int::Errors::GenericTrivial, 'One or more checks failed')
+      .to raise_error(Nanoc::Core::TrivialError, 'One or more checks failed')
       .and output(%r{output/foo\.html:}).to_stdout
   end
 
   it 'fails check for foo.xhtml' do
     expect { Nanoc::CLI.run(%w[check ilinks]) }
-      .to raise_error(Nanoc::Int::Errors::GenericTrivial, 'One or more checks failed')
+      .to raise_error(Nanoc::Core::TrivialError, 'One or more checks failed')
       .and output(%r{output/foo\.xhtml:}).to_stdout
   end
 
   it 'fails check for foo.htm' do
     expect { Nanoc::CLI.run(%w[check ilinks]) }
-      .to raise_error(Nanoc::Int::Errors::GenericTrivial, 'One or more checks failed')
+      .to raise_error(Nanoc::Core::TrivialError, 'One or more checks failed')
       .and output(%r{output/foo\.htm:}).to_stdout
   end
 end
