@@ -15,10 +15,10 @@ describe 'GH-776', site: true do
 EOS
   end
 
-  let(:site) { Nanoc::Int::SiteLoader.new.new_from_cwd }
+  let(:site) { Nanoc::Core::SiteLoader.new.new_from_cwd }
 
   before do
-    site.compile
+    Nanoc::Core::Compiler.compile(site)
   end
 
   context 'without pruning' do
@@ -30,8 +30,8 @@ EOS
 
   context 'with pruning' do
     before do
-      res = Nanoc::Int::Compiler.new_for(site).run_until_reps_built
-      Nanoc::Pruner.new(site.config, res.fetch(:reps)).run
+      res = Nanoc::Core::Compiler.new_for(site).run_until_reps_built
+      Nanoc::Core::Pruner.new(site.config, res.fetch(:reps)).run
     end
 
     it 'does not prune written snapshots' do
