@@ -31,18 +31,49 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def setup
     super
 
-    config = Nanoc::Int::Configuration.new(dir: Dir.getwd).with_defaults
-    items = Nanoc::Int::ItemCollection.new(config)
-    layouts = Nanoc::Int::LayoutCollection.new(config)
-    dep_store = Nanoc::Int::DependencyStore.new(items, layouts, config)
-    dependency_tracker = Nanoc::Int::DependencyTracker.new(dep_store)
+    config = Nanoc::Core::Configuration.new(dir: Dir.getwd).with_defaults
 
-    @view_context = Nanoc::ViewContextForCompilation.new(
-      reps: Nanoc::Int::ItemRepRepo.new,
-      items: Nanoc::Int::ItemCollection.new(config),
+    items = Nanoc::Core::ItemCollection.new(config)
+    layouts = Nanoc::Core::LayoutCollection.new(config)
+    reps = Nanoc::Core::ItemRepRepo.new
+
+    site =
+      Nanoc::Core::Site.new(
+        config: config,
+        code_snippets: [],
+        data_source: Nanoc::Core::InMemoryDataSource.new(items, layouts),
+      )
+
+    dep_store = Nanoc::Core::DependencyStore.new(items, layouts, config)
+    dependency_tracker = Nanoc::Core::DependencyTracker.new(dep_store)
+
+    compiled_content_cache = Nanoc::Core::CompiledContentCache.new(config: config)
+    compiled_content_store = Nanoc::Core::CompiledContentStore.new
+
+    action_provider =
+      Class.new(Nanoc::Core::ActionProvider) do
+        def self.for(_context)
+          raise NotImplementedError
+        end
+
+        def initialize; end
+      end.new
+
+    compilation_context =
+      Nanoc::Core::CompilationContext.new(
+        action_provider: action_provider,
+        reps: reps,
+        site: site,
+        compiled_content_cache: compiled_content_cache,
+        compiled_content_store: compiled_content_store,
+      )
+
+    @view_context = Nanoc::Core::ViewContextForCompilation.new(
+      reps: reps,
+      items: items,
       dependency_tracker: dependency_tracker,
-      compilation_context: :__irrelevant__,
-      snapshot_repo: :__irrelevant_snapshot_repo,
+      compilation_context: compilation_context,
+      compiled_content_store: Nanoc::Core::CompiledContentStore.new,
     )
   end
 
@@ -68,8 +99,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[2].expects(:compiled_content).with(snapshot: :pre).returns('item 2 content')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -98,8 +129,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[2].expects(:compiled_content).returns('item 2 content')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -128,8 +159,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[2].expects(:compiled_content).returns('item 2 content')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -158,8 +189,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[2].expects(:compiled_content).returns('item 2 content')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -178,8 +209,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_item, mock_item]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -188,7 +219,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
     # Check
-    error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
+    error = assert_raises(Nanoc::Core::TrivialError) do
       atom_feed
     end
     assert_equal(
@@ -202,8 +233,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_item, mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: nil }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: nil }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -212,7 +243,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
     # Check
-    error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
+    error = assert_raises(Nanoc::Core::TrivialError) do
       atom_feed
     end
     assert_equal(
@@ -226,8 +257,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_item, mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -236,7 +267,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
     # Check
-    error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
+    error = assert_raises(Nanoc::Core::TrivialError) do
       atom_feed
     end
     assert_equal(
@@ -250,8 +281,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_item, mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -260,7 +291,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
     # Check
-    error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
+    error = assert_raises(Nanoc::Core::TrivialError) do
       atom_feed
     end
     assert_equal(
@@ -279,8 +310,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[0].expects(:compiled_content).returns('item 1 content')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com/' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com/' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -308,8 +339,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_item, mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -318,7 +349,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @item.stubs(:[]).with(:author_uri).returns(nil)
 
     # Check
-    error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
+    error = assert_raises(Nanoc::Core::TrivialError) do
       atom_feed
     end
     assert_equal(
@@ -334,8 +365,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[2].stubs(:[]).with(:created_at).returns(nil)
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -344,7 +375,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
 
     # Check
-    error = assert_raises(Nanoc::Int::Errors::GenericTrivial) do
+    error = assert_raises(Nanoc::Core::TrivialError) do
       atom_feed
     end
     assert_equal(
@@ -359,8 +390,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -390,8 +421,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
         title: 'My Blog Or Something',
         base_url: 'http://example.com',
       }
-    config = Nanoc::Int::Configuration.new(hash: config_hash, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: config_hash, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -413,8 +444,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -436,8 +467,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     end
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -468,8 +499,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[1].stubs(:[]).with(:created_at).returns('22-03-2009')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -496,8 +527,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[1].stubs(:[]).with(:created_at).returns('01-01-2014')
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -519,8 +550,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -539,8 +570,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -559,8 +590,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -579,8 +610,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -599,8 +630,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -619,8 +650,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [mock_article]
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -640,8 +671,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items[0].stubs(:path).returns(nil)
 
     # Mock site
-    config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-    @config = Nanoc::ConfigView.new(config, @view_context)
+    config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+    @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
     # Create feed item
     @item = mock
@@ -663,8 +694,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
-      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-      @config = Nanoc::ConfigView.new(config, @view_context)
+      config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+      @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -690,8 +721,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
-      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-      @config = Nanoc::ConfigView.new(config, @view_context)
+      config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+      @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -717,8 +748,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
-      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-      @config = Nanoc::ConfigView.new(config, @view_context)
+      config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+      @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -734,6 +765,35 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       elements = doc.xpath('/atom:feed/atom:link[@rel=\'alternate\']', atom: 'http://www.w3.org/2005/Atom')
       assert_equal 1, elements.size
       assert_equal 'http://example.com/', elements[0].attribute('href').inner_text
+      assert_equal 'text/html', elements[0].attribute('type').inner_text
+    end
+  end
+
+  def test_atom_feed_self_link
+    if_have 'nokogiri' do
+      # Create items
+      @items = [mock_article]
+      @items[0].stubs(:path).returns(nil)
+
+      # Mock site
+      config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+      @config = Nanoc::Core::ConfigView.new(config, @view_context)
+
+      # Create feed item
+      @item = mock
+      @item.stubs(:identifier).returns('/feed/')
+      @item.stubs(:[]).with(:title).returns('My Cool Blog')
+      @item.stubs(:[]).with(:author_name).returns('Denis Defreyne')
+      @item.stubs(:[]).with(:author_uri).returns('http://stoneship.org/')
+      @item.stubs(:[]).with(:feed_url).returns(nil)
+      @item.stubs(:path).returns('/journal/feed/')
+
+      # Check
+      doc = Nokogiri::XML(atom_feed)
+      elements = doc.xpath('/atom:feed/atom:link[@rel=\'self\']', atom: 'http://www.w3.org/2005/Atom')
+      assert_equal 1, elements.size
+      assert_equal 'http://example.com/journal/feed/', elements[0].attribute('href').inner_text
+      assert_equal 'application/atom+xml', elements[0].attribute('type').inner_text
     end
   end
 
@@ -744,8 +804,8 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
-      config = Nanoc::Int::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
-      @config = Nanoc::ConfigView.new(config, @view_context)
+      config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+      @config = Nanoc::Core::ConfigView.new(config, @view_context)
 
       # Create feed item
       @item = mock
@@ -763,4 +823,34 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       assert_equal '/blog/', elements[0].attribute('href').inner_text
     end
   end
+
+  def test_atom_feed_article_alt_link
+    if_have 'nokogiri' do
+      # Create items
+      @items = [mock_article]
+      @items[0].stubs(:[]).with(:title).returns('Some Article')
+      @items[0].stubs(:[]).with(:created_at).returns('01-01-2015')
+      @items[0].stubs(:path).returns('/some-article/')
+
+      # Mock site
+      config = Nanoc::Core::Configuration.new(hash: { base_url: 'http://example.com' }, dir: Dir.getwd)
+      @config = Nanoc::Core::ConfigView.new(config, @view_context)
+
+      # Create feed item
+      @item = mock
+      @item.stubs(:identifier).returns('/feed/')
+      @item.stubs(:[]).with(:title).returns('My Cool Blog')
+      @item.stubs(:[]).with(:author_name).returns('Denis Defreyne')
+      @item.stubs(:[]).with(:author_uri).returns('http://stoneship.org/')
+      @item.stubs(:[]).with(:feed_url).returns(nil)
+      @item.stubs(:path).returns('/journal/feed/')
+
+      # Check
+      doc = Nokogiri::XML(atom_feed)
+      elements = doc.xpath('/atom:feed/atom:entry/atom:link[@rel=\'alternate\']', atom: 'http://www.w3.org/2005/Atom')
+      assert_equal 1, elements.size
+      assert_equal 'http://example.com/some-article/', elements[0].attribute('href').inner_text
+      assert_equal 'text/html', elements[0].attribute('type').inner_text
+    end
+  end
 end
